@@ -2,10 +2,8 @@ from dataclasses import dataclass
 from enum import Enum
 
 import google.protobuf.message
-from nibiru_proto.proto.dex.v1 import tx_pb2 as dex_events  # noqa
-from nibiru_proto.proto.lockup.v1 import tx_pb2 as lockup_events  # noqa
 from nibiru_proto.proto.perp.v1 import event_pb2 as perp_events
-from nibiru_proto.proto.pricefeed import tx_pb2 as pricefeed_events
+from nibiru_proto.proto.spot.v1 import event_pb2 as spot_events
 from nibiru_proto.proto.stablecoin import events_pb2 as stablecoin_events  # noqa
 from nibiru_proto.proto.vpool.v1 import event_pb2 as vpool_events
 
@@ -26,29 +24,20 @@ class EventType(Enum):
     SwapOnVpoolEvent = vpool_events.SwapOnVpoolEvent
     MarkPriceChanged = vpool_events.MarkPriceChangedEvent
 
-    # # Dex event
-    # PoolJoinedEvent = dex_events.EventPoolJoined
-    # PoolCreatedEvent = dex_events.EventPoolCreated
-    # PoolExitedEvent = dex_events.EventPoolExited
-    # AssetsSwappedEvent = dex_events.EventAssetsSwapped
-
-    # Lockup event
-    # LockEvent = lockup_events.EventLock
-    # UnlockInitiatedEvent = lockup_events.EventUnlockInitiated
-    # UnlockEvent = lockup_events.EventUnlock
-
-    # Pricefeed events
-    OracleUpdatePriceEvent = pricefeed_events.EventOracleUpdatePrice
-    PairPriceUpdatedEvent = pricefeed_events.EventPairPriceUpdated
+    # Spot event
+    PoolJoinedEvent = spot_events.EventPoolJoined
+    PoolCreatedEvent = spot_events.EventPoolCreated
+    PoolExitedEvent = spot_events.EventPoolExited
+    AssetsSwappedEvent = spot_events.EventAssetsSwapped
 
     # Stablecoin events
-    # TransferEvent = stablecoin_events.EventTransfer
-    # MintStableEvent = stablecoin_events.EventMintStable
-    # BurnStableEvent = stablecoin_events.EventBurnStable
-    # MintNIBIEvent = stablecoin_events.EventMintNIBI
-    # BurnNIBIEvent = stablecoin_events.EventBurnNIBI
-    # RecollateralizeEvent = stablecoin_events.EventRecollateralize
-    # BuybackEvent = stablecoin_events.EventBuyback
+    TransferEvent = stablecoin_events.EventTransfer
+    MintStableEvent = stablecoin_events.EventMintStable
+    BurnStableEvent = stablecoin_events.EventBurnStable
+    MintNIBIEvent = stablecoin_events.EventMintNIBI
+    BurnNIBIEvent = stablecoin_events.EventBurnNIBI
+    RecollateralizeEvent = stablecoin_events.EventRecollateralize
+    BuybackEvent = stablecoin_events.EventBuyback
 
     # Bank
     Transfer = "transfer"
