@@ -68,13 +68,13 @@ class GrpcClient:
         self.timeout_height = 1
 
         # Query services
-        self.dex = query_clients.DexQueryClient(self.chain_channel)
-        self.pricefeed = query_clients.PricefeedQueryClient(self.chain_channel)
+        self.spot = query_clients.SpotQueryClient(self.chain_channel)
         self.perp = query_clients.PerpQueryClient(self.chain_channel)
         self.vpool = query_clients.VpoolQueryClient(self.chain_channel)
         self.epoch = query_clients.EpochQueryClient(self.chain_channel)
         self.auth = query_clients.AuthQueryClient(self.chain_channel)
         self.staking = query_clients.StakingQueryClient(self.chain_channel)
+        self.util = query_clients.UtilQueryClient(self.chain_channel)
 
         if not bypass_version_check:
             try:
@@ -113,7 +113,6 @@ class GrpcClient:
                 f"The chain is running a custom release from branch/commit {chain_nibiru_version}"
             )
         else:
-
             error_string = (
                 f"Version error, Python sdk runs with nibiru protobuf version {nibiru_proto_version}, but the "
                 f"remote chain is running with version {chain_nibiru_version}"
