@@ -13,5 +13,5 @@ from nibiru.pytypes.common import (  # noqa # TODO move constants to a constants
     TxType,
 )
 from nibiru.pytypes.event import Event, RawEvent, TxLogEvents  # noqa
-from nibiru.pytypes.network import Network  # noqa
+from nibiru.pytypes.network import Network, NetworkType  # noqa
 from nibiru.pytypes.tx_resp import RawTxResp, TxResp  # noqa
