@@ -1,8 +1,7 @@
 from nibiru.query_clients.auth import AuthQueryClient  # noqa
-from nibiru.query_clients.dex import DexQueryClient  # noqa
 from nibiru.query_clients.epoch import EpochQueryClient  # noqa
 from nibiru.query_clients.perp import PerpQueryClient  # noqa
-from nibiru.query_clients.pricefeed import PricefeedQueryClient  # noqa
+from nibiru.query_clients.spot import SpotQueryClient  # noqa
 from nibiru.query_clients.staking import StakingQueryClient  # noqa
 from nibiru.query_clients.util import *  # noqa
 from nibiru.query_clients.vpool import VpoolQueryClient  # noqa
